# PyOTIC
A Python package to calibrate optical tweezers by power spectral density analysis (PyOTC) and efficiently analyze time-dependent signals (PyOTI).

# Cite as follows:
Simmert, S. and Jachowski, T.J. (2020). PyOTIC: A Python package to calibrate optical tweezers and analyze time-dependent signals. GitHub repository: https://github.com/cellular-nanoscience/pyotic
